@@ -55,7 +55,10 @@ check_button_changed (GtkWidget *button, CpuFreqPluginConfigure *configure)
   if (!cpuFreq->options->show_label_freq && !cpuFreq->options->show_label_governor)
   {
     if (!cpuFreq->options->show_icon)
+    {
+      cpuFreq->options->show_icon = TRUE;
       gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (configure->display_icon), TRUE);
+    }
 
     gtk_widget_set_sensitive (configure->display_icon, FALSE);
   }
@@ -64,6 +67,7 @@ check_button_changed (GtkWidget *button, CpuFreqPluginConfigure *configure)
     gtk_widget_set_sensitive (configure->display_icon, TRUE);
   }
 
+  cpufreq_prepare_label (cpuFreq);
   cpufreq_update_icon (cpuFreq);
   cpufreq_update_plugin (TRUE);
 }
@@ -164,19 +168,33 @@ button_fontcolor_clicked (GtkWidget *button, void *data)
 static void
 combo_changed (GtkWidget *combo, CpuFreqPluginConfigure *configure)
 {
+  CpuFreqPluginOptions *const options = cpuFreq->options;
   guint selected = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 
   if (GTK_WIDGET (combo) == configure->combo_cpu)
   {
     guint num_cpus = cpuFreq->cpus->len;
     if (selected < num_cpus)
-      cpuFreq->options->show_cpu = selected;
+      options->show_cpu = selected;
     else if (selected == num_cpus + 0)
-      cpuFreq->options->show_cpu = CPU_MIN;
+      options->show_cpu = CPU_MIN;
     else if (selected == num_cpus + 1)
-      cpuFreq->options->show_cpu = CPU_AVG;
+      options->show_cpu = CPU_AVG;
     else if (selected == num_cpus + 2)
-      cpuFreq->options->show_cpu = CPU_MAX;
+      options->show_cpu = CPU_MAX;
+
+    cpufreq_update_plugin (TRUE);
+  }
+  else if (GTK_WIDGET (combo) == configure->combo_unit)
+  {
+    switch (selected)
+    {
+    case UNIT_AUTO:
+    case UNIT_GHZ:
+    case UNIT_MHZ:
+      options->unit = (CpuFreqUnit) selected;
+      break;
+    }
 
     cpufreq_update_plugin (TRUE);
   }
@@ -210,10 +228,11 @@ cpufreq_configure_response (GtkWidget *dialog, int response, CpuFreqPluginConfig
 void
 cpufreq_configure (XfcePanelPlugin *plugin)
 {
+  CpuFreqPluginOptions *const options = cpuFreq->options;
   gchar *cpu_name;
   GtkWidget *dialog, *dialog_vbox;
   GtkWidget *frame, *align, *label, *vbox, *hbox;
-  GtkWidget *combo, *spinner, *button;
+  GtkWidget *spinner, *button;
   GtkSizeGroup *sg0;
   CpuFreqPluginConfigure *configure;
   GdkRGBA *color;
@@ -271,7 +290,7 @@ cpufreq_configure (XfcePanelPlugin *plugin)
   spinner = configure->spinner_timeout =
     gtk_spin_button_new_with_range (TIMEOUT_MIN, TIMEOUT_MAX, TIMEOUT_STEP);
   gtk_label_set_mnemonic_widget (GTK_LABEL (label), spinner);
-  gtk_spin_button_set_value (GTK_SPIN_BUTTON (spinner), (gdouble) cpuFreq->options->timeout);
+  gtk_spin_button_set_value (GTK_SPIN_BUTTON (spinner), (gdouble) options->timeout);
   gtk_box_pack_start (GTK_BOX (hbox), spinner, FALSE, FALSE, 0);
   g_signal_connect (G_OBJECT (spinner), "value-changed",
                     G_CALLBACK (spinner_changed), configure);
@@ -328,7 +347,7 @@ cpufreq_configure (XfcePanelPlugin *plugin)
   gtk_size_group_add_widget (sg0, label);
 
   color = g_new0 (GdkRGBA, 1);
-  gdk_rgba_parse (color, cpuFreq->options->fontcolor ? cpuFreq->options->fontcolor : "#000000");
+  gdk_rgba_parse (color, options->fontcolor ? options->fontcolor : "#000000");
 
   button = configure->fontcolor = gtk_color_button_new_with_rgba (color);
   gtk_color_button_set_title (GTK_COLOR_BUTTON (button), _("Select font color"));
@@ -338,79 +357,125 @@ cpufreq_configure (XfcePanelPlugin *plugin)
   g_free (color);
 
   /* which cpu to show in panel */
-  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
-  gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
-
-  label = gtk_label_new_with_mnemonic (_("_Display CPU:"));
-  gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-  gtk_widget_set_valign (label, GTK_ALIGN_CENTER);
-  gtk_label_set_xalign (GTK_LABEL (label), 0);
-  gtk_size_group_add_widget (sg0, label);
-
-  combo = configure->combo_cpu = gtk_combo_box_text_new ();
-  gtk_box_pack_start (GTK_BOX (hbox), combo, FALSE, TRUE, 0);
-  gtk_label_set_mnemonic_widget (GTK_LABEL (label), combo);
-
-  for (guint i = 0; i < cpuFreq->cpus->len; ++i)
   {
-    cpu_name = g_strdup_printf ("%d", i);
-    gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo), cpu_name);
-    g_free (cpu_name);
-  }
+    GtkWidget *combo;
 
-  gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo), _("min"));
-  gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo), _("avg"));
-  gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo), _("max"));
+    hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
+    gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
-retry:
-  switch (cpuFreq->options->show_cpu)
-  {
-  case CPU_MIN:
-    gtk_combo_box_set_active (GTK_COMBO_BOX (combo), cpuFreq->cpus->len + 0);
-    break;
-  case CPU_AVG:
-    gtk_combo_box_set_active (GTK_COMBO_BOX (combo), cpuFreq->cpus->len + 1);
-    break;
-  case CPU_MAX:
-    gtk_combo_box_set_active (GTK_COMBO_BOX (combo), cpuFreq->cpus->len + 2);
-    break;
-  default:
-    if (cpuFreq->options->show_cpu >= 0 && cpuFreq->options->show_cpu < (gint) cpuFreq->cpus->len)
-      gtk_combo_box_set_active (GTK_COMBO_BOX (combo), cpuFreq->options->show_cpu);
-    else
+    label = gtk_label_new_with_mnemonic (_("_Display CPU:"));
+    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+    gtk_widget_set_valign (label, GTK_ALIGN_CENTER);
+    gtk_label_set_xalign (GTK_LABEL (label), 0);
+    gtk_size_group_add_widget (sg0, label);
+
+    combo = configure->combo_cpu = gtk_combo_box_text_new ();
+    gtk_box_pack_start (GTK_BOX (hbox), combo, FALSE, TRUE, 0);
+    gtk_label_set_mnemonic_widget (GTK_LABEL (label), combo);
+
+    for (guint i = 0; i < cpuFreq->cpus->len; ++i)
     {
-      cpuFreq->options->show_cpu = CPU_DEFAULT;
-      goto retry;
+      cpu_name = g_strdup_printf ("%d", i);
+      gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo), cpu_name);
+      g_free (cpu_name);
     }
+
+    gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo), _("min"));
+    gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo), _("avg"));
+    gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo), _("max"));
+
+  retry_cpu:
+    switch (options->show_cpu)
+    {
+    case CPU_MIN:
+      gtk_combo_box_set_active (GTK_COMBO_BOX (combo), cpuFreq->cpus->len + 0);
+      break;
+    case CPU_AVG:
+      gtk_combo_box_set_active (GTK_COMBO_BOX (combo), cpuFreq->cpus->len + 1);
+      break;
+    case CPU_MAX:
+      gtk_combo_box_set_active (GTK_COMBO_BOX (combo), cpuFreq->cpus->len + 2);
+      break;
+    default:
+      if (options->show_cpu >= 0 && options->show_cpu < (gint) cpuFreq->cpus->len)
+        gtk_combo_box_set_active (GTK_COMBO_BOX (combo), options->show_cpu);
+      else
+      {
+        options->show_cpu = CPU_DEFAULT;
+        goto retry_cpu;
+      }
+    }
+
+    g_signal_connect (G_OBJECT (combo), "changed", G_CALLBACK (combo_changed), configure);
+  }
+
+  /* which unit to use when displaying the frequency */
+  {
+    GtkWidget *combo;
+
+    hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
+    gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
+
+    label = gtk_label_new_with_mnemonic (_("Unit:"));
+    gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+    gtk_widget_set_valign (label, GTK_ALIGN_CENTER);
+    gtk_label_set_xalign (GTK_LABEL (label), 0);
+    gtk_size_group_add_widget (sg0, label);
+
+    combo = configure->combo_unit = gtk_combo_box_text_new ();
+    gtk_box_pack_start (GTK_BOX (hbox), combo, FALSE, TRUE, 0);
+    gtk_label_set_mnemonic_widget (GTK_LABEL (label), combo);
+
+    gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo), _("Auto"));
+    gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo), _("GHz"));
+    gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo), _("MHz"));
+
+  retry_unit:
+    switch (options->unit)
+    {
+    case UNIT_AUTO:
+      gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
+      break;
+    case UNIT_GHZ:
+      gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 1);
+      break;
+    case UNIT_MHZ:
+      gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 2);
+      break;
+    default:
+      options->unit = UNIT_DEFAULT;
+      goto retry_unit;
+    }
+
+    g_signal_connect (G_OBJECT (combo), "changed", G_CALLBACK (combo_changed), configure);
   }
-  g_signal_connect (G_OBJECT (combo), "changed", G_CALLBACK (combo_changed), configure);
 
   /* check buttons for display widgets in panel */
   button = configure->keep_compact = gtk_check_button_new_with_mnemonic (_("_Keep compact"));
   gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
-  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), cpuFreq->options->keep_compact);
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), options->keep_compact);
   g_signal_connect (G_OBJECT (button), "toggled", G_CALLBACK (check_button_changed), configure);
 
   button = configure->one_line = gtk_check_button_new_with_mnemonic (_("Show text in a single _line"));
   gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
-  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), cpuFreq->options->one_line);
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), options->one_line);
   g_signal_connect (G_OBJECT (button), "toggled", G_CALLBACK (check_button_changed), configure);
 
   button = configure->display_icon = gtk_check_button_new_with_mnemonic (_("Show CPU _icon"));
   gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
-  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), cpuFreq->options->show_icon);
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), options->show_icon);
   g_signal_connect (G_OBJECT (button), "toggled", G_CALLBACK (check_button_changed), configure);
-  if (!cpuFreq->options->show_label_freq && !cpuFreq->options->show_label_governor)
+  if (!options->show_label_freq && !options->show_label_governor)
     gtk_widget_set_sensitive (configure->display_icon, FALSE);
 
   button = configure->display_freq = gtk_check_button_new_with_mnemonic (_("Show CPU fre_quency"));
   gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
-  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), cpuFreq->options->show_label_freq);
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), options->show_label_freq);
   g_signal_connect (G_OBJECT (button), "toggled", G_CALLBACK (check_button_changed), configure);
 
   button = configure->display_governor = gtk_check_button_new_with_mnemonic (_("Show CPU _governor"));
   gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
-  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), cpuFreq->options->show_label_governor);
+  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), options->show_label_governor);
   g_signal_connect (G_OBJECT (button), "toggled", G_CALLBACK (check_button_changed), configure);
 
   g_signal_connect(G_OBJECT (dialog), "response", G_CALLBACK(cpufreq_configure_response), configure);
