@@ -27,6 +27,7 @@
 #endif
 
 #include <libxfce4ui/libxfce4ui.h>
+#include <string.h>
 
 #include "xfce4-cpufreq-plugin.h"
 #include "xfce4-cpufreq-configure.h"
@@ -44,10 +45,13 @@ cpufreq_label_set_font (void)
 {
   gchar *css = NULL, *css_font = NULL, *css_color = NULL;
   PangoFontDescription *font;
+  GtkWidget *label;
 
-  if (G_UNLIKELY (cpuFreq->label == NULL))
+  if (G_UNLIKELY (cpuFreq->label_orNull == NULL))
     return;
 
+  label = cpuFreq->label_orNull;
+
   if (cpuFreq->options->fontname)
   {
     font = pango_font_description_from_string(cpuFreq->options->fontname);
@@ -79,7 +83,7 @@ cpufreq_label_set_font (void)
     if (cpuFreq->label_css_provider)
     {
       gtk_style_context_remove_provider (
-        GTK_STYLE_CONTEXT (gtk_widget_get_style_context (cpuFreq->label)),
+        GTK_STYLE_CONTEXT (gtk_widget_get_style_context (label)),
         GTK_STYLE_PROVIDER (cpuFreq->label_css_provider));
       cpuFreq->label_css_provider = NULL;
     }
@@ -88,7 +92,7 @@ cpufreq_label_set_font (void)
 
     gtk_css_provider_load_from_data (provider, css, -1, NULL);
     gtk_style_context_add_provider (
-      GTK_STYLE_CONTEXT (gtk_widget_get_style_context (cpuFreq->label)),
+      GTK_STYLE_CONTEXT (gtk_widget_get_style_context (label)),
       GTK_STYLE_PROVIDER (provider), GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
 
     cpuFreq->label_css_provider = provider;
@@ -102,31 +106,73 @@ cpufreq_label_set_font (void)
 
 
 /*
- * Returns a valid string if all CPUs have the same governor,
- * otherwise returns NULL.
+ * Returns a single string describing governors of all CPUs, or NULL.
+ * The returned string should be freed with g_free().
  */
-static const gchar*
-cpufreq_cpus_single_governor ()
+static gchar*
+cpufreq_governors (void)
 {
-  const gchar *governor = NULL;
+  const gchar *array[cpuFreq->cpus->len];
+  guint count = 0;
+
+  if (cpuFreq->cpus->len == 0)
+    return NULL;
 
   for (guint i = 0; i < cpuFreq->cpus->len; i++)
   {
     CpuInfo *cpu = g_ptr_array_index (cpuFreq->cpus, i);
+    guint j;
 
     if (!cpu->online)
       continue;
 
     if (!cpu->cur_governor || cpu->cur_governor[0] == '\0')
-      return NULL;
+      continue;
 
-    if (!governor)
-      governor = cpu->cur_governor;
-    else if (strcmp (governor, cpu->cur_governor) != 0)
-      return NULL;
+    for (j = 0; j < count; j++)
+      if (strcmp (cpu->cur_governor, array[j]) == 0)
+        break;
+    if (j == count)
+      array[count++] = cpu->cur_governor;
   }
 
-  return governor;
+  if (count != 0)
+  {
+    gchar *s;
+    gsize s_length;
+
+    // Bubble sort
+    for (guint i = 0; G_UNLIKELY (i < count-1); i++)
+      for (guint j = i+1; j < count; j++)
+        if (strcmp (array[i], array[j]) > 0)
+        {
+          const gchar *tmp = array[i];
+          array[i] = array[j];
+          array[j] = tmp;
+        }
+
+    s_length = (count-1) * strlen (",");
+    for (guint i = 0; i < count; i++)
+      s_length += strlen (array[i]);
+
+    s = g_malloc (s_length+1);
+
+    s_length = 0;
+    for (guint i = 0; i < count; i++)
+    {
+      if (i)
+        s[s_length++] = ',';
+      strcpy (s + s_length, array[i]);
+      s_length += strlen (array[i]);
+    }
+    s[s_length] = '\0';
+
+    return s;
+  }
+  else
+  {
+    return NULL;
+  }
 }
 
 
@@ -134,7 +180,8 @@ cpufreq_cpus_single_governor ()
 static CpuInfo *
 cpufreq_cpus_calc_min (void)
 {
-  const gchar *const governor = cpufreq_cpus_single_governor ();
+  gchar *const governors = cpufreq_governors ();
+  gchar *const old_governor = cpuFreq->cpu_min ? g_strdup (cpuFreq->cpu_min->cur_governor) : g_strdup ("");
   guint freq = 0;
 
   for (guint i = 0; i < cpuFreq->cpus->len; i++)
@@ -151,8 +198,15 @@ cpufreq_cpus_calc_min (void)
   cpuinfo_free (cpuFreq->cpu_min);
   cpuFreq->cpu_min = g_new0 (CpuInfo, 1);
   cpuFreq->cpu_min->cur_freq = freq;
-  cpuFreq->cpu_min->cur_governor = g_strdup (governor ? governor : _("current min"));
+  cpuFreq->cpu_min->cur_governor = governors ? governors : g_strdup (_("current min"));
 
+  if (cpuFreq->options->show_label_governor && strcmp(cpuFreq->cpu_min->cur_governor, old_governor) != 0)
+  {
+    cpuFreq->layout_changed = TRUE;
+    cpuFreq->label_max_width = -1;
+  }
+
+  g_free (old_governor);
   return cpuFreq->cpu_min;
 }
 
@@ -161,7 +215,8 @@ cpufreq_cpus_calc_min (void)
 static CpuInfo *
 cpufreq_cpus_calc_avg (void)
 {
-  const gchar *const governor = cpufreq_cpus_single_governor ();
+  gchar *const governors = cpufreq_governors ();
+  gchar *const old_governor = cpuFreq->cpu_avg ? g_strdup (cpuFreq->cpu_avg->cur_governor) : g_strdup ("");
   guint freq = 0, count = 0;
 
   for (guint i = 0; i < cpuFreq->cpus->len; i++)
@@ -181,8 +236,15 @@ cpufreq_cpus_calc_avg (void)
   cpuinfo_free (cpuFreq->cpu_avg);
   cpuFreq->cpu_avg = g_new0 (CpuInfo, 1);
   cpuFreq->cpu_avg->cur_freq = freq;
-  cpuFreq->cpu_avg->cur_governor = g_strdup (governor ? governor : _("current avg"));
+  cpuFreq->cpu_avg->cur_governor = governors ? governors : g_strdup (_("current avg"));
 
+  if (cpuFreq->options->show_label_governor && strcmp(cpuFreq->cpu_avg->cur_governor, old_governor) != 0)
+  {
+    cpuFreq->layout_changed = TRUE;
+    cpuFreq->label_max_width = -1;
+  }
+
+  g_free (old_governor);
   return cpuFreq->cpu_avg;
 }
 
@@ -191,7 +253,8 @@ cpufreq_cpus_calc_avg (void)
 static CpuInfo *
 cpufreq_cpus_calc_max (void)
 {
-  const gchar *const governor = cpufreq_cpus_single_governor ();
+  gchar *const governors = cpufreq_governors ();
+  gchar *const old_governor = cpuFreq->cpu_max ? g_strdup (cpuFreq->cpu_max->cur_governor) : g_strdup ("");
   guint freq = 0;
 
   for (guint i = 0; i < cpuFreq->cpus->len; i++)
@@ -208,8 +271,15 @@ cpufreq_cpus_calc_max (void)
   cpuinfo_free (cpuFreq->cpu_max);
   cpuFreq->cpu_max = g_new0 (CpuInfo, 1);
   cpuFreq->cpu_max->cur_freq = freq;
-  cpuFreq->cpu_max->cur_governor = g_strdup (governor ? governor : _("current max"));
+  cpuFreq->cpu_max->cur_governor = governors ? governors : g_strdup (_("current max"));
 
+  if (cpuFreq->options->show_label_governor && strcmp(cpuFreq->cpu_max->cur_governor, old_governor) != 0)
+  {
+    cpuFreq->layout_changed = TRUE;
+    cpuFreq->label_max_width = -1;
+  }
+
+  g_free (old_governor);
   return cpuFreq->cpu_max;
 }
 
@@ -218,14 +288,18 @@ cpufreq_cpus_calc_max (void)
 static gboolean
 cpufreq_update_label (CpuInfo *cpu)
 {
+  GtkWidget *label_widget;
   GtkRequisition label_size;
   gchar *label, *freq;
   gint both;
 
-  if (!cpuFreq->options->show_label_governor && !cpuFreq->options->show_label_freq) {
-    if (cpuFreq->label != NULL)
-      gtk_widget_hide (cpuFreq->label);
+  if (!cpuFreq->label_orNull)
+    return TRUE;
 
+  label_widget = cpuFreq->label_orNull;
+
+  if (!cpuFreq->options->show_label_governor && !cpuFreq->options->show_label_freq) {
+    gtk_widget_hide (label_widget);
     return TRUE;
   }
 
@@ -233,7 +307,7 @@ cpufreq_update_label (CpuInfo *cpu)
     cpuFreq->options->show_label_freq &&
     cpuFreq->options->show_label_governor;
 
-  freq = cpufreq_get_human_readable_freq (cpu->cur_freq);
+  freq = cpufreq_get_human_readable_freq (cpu->cur_freq, cpuFreq->options->unit);
   label = g_strconcat
     (cpuFreq->options->show_label_freq ? freq : "",
      both ? (cpuFreq->options->one_line ? " " : "\n") : "",
@@ -241,26 +315,25 @@ cpufreq_update_label (CpuInfo *cpu)
      cpuFreq->options->show_label_governor ? cpu->cur_governor : "",
      NULL);
 
-  gtk_label_set_text (GTK_LABEL (cpuFreq->label), label);
+  gtk_label_set_text (GTK_LABEL (label_widget), label);
 
   if (strcmp(label, ""))
   {
     if (cpuFreq->panel_mode == XFCE_PANEL_PLUGIN_MODE_VERTICAL)
-      gtk_label_set_angle (GTK_LABEL(cpuFreq->label), -90);
+      gtk_label_set_angle (GTK_LABEL(label_widget), -90);
     else
-      gtk_label_set_angle (GTK_LABEL(cpuFreq->label), 0);
+      gtk_label_set_angle (GTK_LABEL(label_widget), 0);
 
-    gtk_widget_show (cpuFreq->label);
+    gtk_widget_show (label_widget);
 
     /* Set label width to max width if smaller to avoid panel
        resizing/jumping (see bug #10385). */
-    gtk_widget_get_preferred_size (cpuFreq->label, NULL, &label_size);
+    gtk_widget_get_preferred_size (label_widget, NULL, &label_size);
     if (cpuFreq->panel_mode == XFCE_PANEL_PLUGIN_MODE_VERTICAL)
     {
       if (label_size.height < cpuFreq->label_max_width)
       {
-        gtk_widget_set_size_request (GTK_WIDGET (cpuFreq->label),
-          -1, cpuFreq->label_max_width);
+        gtk_widget_set_size_request (label_widget, -1, cpuFreq->label_max_width);
       }
       else if (label_size.height > cpuFreq->label_max_width)
       {
@@ -272,8 +345,7 @@ cpufreq_update_label (CpuInfo *cpu)
     {
       if (label_size.width < cpuFreq->label_max_width)
       {
-        gtk_widget_set_size_request (GTK_WIDGET (cpuFreq->label),
-          cpuFreq->label_max_width, -1);
+        gtk_widget_set_size_request (label_widget, cpuFreq->label_max_width, -1);
       }
       else if (label_size.width > cpuFreq->label_max_width)
       {
@@ -284,7 +356,7 @@ cpufreq_update_label (CpuInfo *cpu)
   }
   else
   {
-    gtk_widget_hide (cpuFreq->label);
+    gtk_widget_hide (label_widget);
   }
 
   g_free (freq);
@@ -326,9 +398,9 @@ cpufreq_widgets_layout (void)
   }
 
   /* check if the label fits below the icon, else put them side by side */
-  if (GTK_IS_WIDGET(cpuFreq->label) && ! hide_label)
+  if (cpuFreq->label_orNull && ! hide_label)
   {
-    gtk_widget_get_preferred_size (cpuFreq->label, NULL, &label_size);
+    gtk_widget_get_preferred_size (cpuFreq->label_orNull, NULL, &label_size);
     lw = label_size.width;
     lh = label_size.height;
   }
@@ -362,19 +434,19 @@ cpufreq_widgets_layout (void)
   {
       if (cpuFreq->icon)
         gtk_widget_set_halign (cpuFreq->icon, GTK_ALIGN_CENTER);
-      if (cpuFreq->label)
-        gtk_widget_set_halign (cpuFreq->label, GTK_ALIGN_CENTER);
+      if (cpuFreq->label_orNull)
+        gtk_widget_set_halign (cpuFreq->label_orNull, GTK_ALIGN_CENTER);
     }
     else
     {
       if (cpuFreq->icon)
         gtk_widget_set_valign (cpuFreq->icon, GTK_ALIGN_CENTER);
-      if (cpuFreq->label)
-        gtk_widget_set_valign (cpuFreq->label, GTK_ALIGN_CENTER);
+      if (cpuFreq->label_orNull)
+        gtk_widget_set_valign (cpuFreq->label_orNull, GTK_ALIGN_CENTER);
     }
 
-    if (cpuFreq->label)
-      gtk_label_set_justify (GTK_LABEL (cpuFreq->label),
+    if (cpuFreq->label_orNull)
+      gtk_label_set_justify (GTK_LABEL (cpuFreq->label_orNull),
         resized ? GTK_JUSTIFY_CENTER : GTK_JUSTIFY_LEFT);
 
     if (cpuFreq->icon)
@@ -391,24 +463,24 @@ cpufreq_widgets_layout (void)
         gtk_widget_set_valign (cpuFreq->icon, GTK_ALIGN_END);
       }
 
-      if (cpuFreq->label)
-        gtk_widget_set_halign (cpuFreq->label, GTK_ALIGN_CENTER);
+      if (cpuFreq->label_orNull)
+        gtk_widget_set_halign (cpuFreq->label_orNull, GTK_ALIGN_CENTER);
     }
     else
     {
       if (cpuFreq->icon)
         gtk_widget_set_valign (cpuFreq->icon, GTK_ALIGN_CENTER);
 
-      if (cpuFreq->label)
+      if (cpuFreq->label_orNull)
       {
-        gtk_widget_set_halign (cpuFreq->label, GTK_ALIGN_END);
-        gtk_widget_set_valign (cpuFreq->label, GTK_ALIGN_CENTER);
+        gtk_widget_set_halign (cpuFreq->label_orNull, GTK_ALIGN_END);
+        gtk_widget_set_valign (cpuFreq->label_orNull, GTK_ALIGN_CENTER);
       }
       pos = resized ? 1 : 0;
     }
 
-    if (cpuFreq->label)
-      gtk_label_set_justify (GTK_LABEL (cpuFreq->label),
+    if (cpuFreq->label_orNull)
+      gtk_label_set_justify (GTK_LABEL (cpuFreq->label_orNull),
         resized ? GTK_JUSTIFY_LEFT : GTK_JUSTIFY_CENTER);
 
     if (cpuFreq->icon)
@@ -416,8 +488,8 @@ cpufreq_widgets_layout (void)
         cpuFreq->icon, TRUE, TRUE, 0, GTK_PACK_START);
   }
 
-  if (cpuFreq->label)
-    gtk_box_reorder_child (GTK_BOX (cpuFreq->box), cpuFreq->label, pos);
+  if (cpuFreq->label_orNull)
+    gtk_box_reorder_child (GTK_BOX (cpuFreq->box), cpuFreq->label_orNull, pos);
 
   cpuFreq->layout_changed = FALSE;
 }
@@ -476,7 +548,8 @@ cpufreq_update_plugin (gboolean reset_label_size)
   if (reset_label_size)
   {
     cpuFreq->label_max_width = -1;
-    gtk_widget_set_size_request (GTK_WIDGET (cpuFreq->label), -1, -1);
+    if (cpuFreq->label_orNull)
+      gtk_widget_set_size_request (cpuFreq->label_orNull, -1, -1);
     cpuFreq->layout_changed = TRUE;
   }
 
@@ -497,8 +570,9 @@ cpufreq_update_tooltip (GtkWidget *widget,
                         gint y,
                         gboolean keyboard_mode,
                         GtkTooltip *tooltip,
-                        CpuFreqPlugin *cpufreq)
+                        CpuFreqPlugin *_unused)
 {
+  const CpuFreqPluginOptions *const options = cpuFreq->options;
   CpuInfo *cpu;
   gchar *tooltip_msg, *freq = NULL;
 
@@ -510,24 +584,24 @@ cpufreq_update_tooltip (GtkWidget *widget,
   }
   else
   {
-    freq = cpufreq_get_human_readable_freq (cpu->cur_freq);
-    if (cpuFreq->options->show_label_governor && cpuFreq->options->show_label_freq)
+    freq = cpufreq_get_human_readable_freq (cpu->cur_freq, options->unit);
+    if (options->show_label_governor && options->show_label_freq)
       tooltip_msg = g_strdup_printf (ngettext ("%d cpu available",
         "%d cpus available", cpuFreq->cpus->len), cpuFreq->cpus->len);
     else
       tooltip_msg =
         g_strconcat
-        (!cpuFreq->options->show_label_freq ? _("Frequency: ") : "",
-         !cpuFreq->options->show_label_freq ? freq : "",
+        (!options->show_label_freq ? _("Frequency: ") : "",
+         !options->show_label_freq ? freq : "",
 
          cpu->cur_governor != NULL &&
-         !cpuFreq->options->show_label_freq &&
-         !cpuFreq->options->show_label_governor ? "\n" : "",
+         !options->show_label_freq &&
+         !options->show_label_governor ? "\n" : "",
 
          cpu->cur_governor != NULL &&
-         !cpuFreq->options->show_label_governor ? _("Governor: ") : "",
+         !options->show_label_governor ? _("Governor: ") : "",
          cpu->cur_governor != NULL &&
-         !cpuFreq->options->show_label_governor ? cpu->cur_governor : "",
+         !options->show_label_governor ? cpu->cur_governor : "",
          NULL);
   }
 
@@ -608,27 +682,27 @@ cpufreq_update_icon (CpuFreqPlugin *cpufreq)
 
 
 
-static void
+void
 cpufreq_prepare_label (CpuFreqPlugin *cpufreq)
 {
-  if (cpufreq->label)
+  if (cpufreq->label_orNull)
   {
     if (cpuFreq->label_css_provider)
     {
       gtk_style_context_remove_provider (
-        GTK_STYLE_CONTEXT (gtk_widget_get_style_context (cpuFreq->label)),
+        GTK_STYLE_CONTEXT (gtk_widget_get_style_context (cpuFreq->label_orNull)),
         GTK_STYLE_PROVIDER (cpuFreq->label_css_provider));
       cpuFreq->label_css_provider = NULL;
     }
 
-    gtk_widget_destroy (cpufreq->label);
-    cpufreq->label = NULL;
+    gtk_widget_destroy (cpufreq->label_orNull);
+    cpufreq->label_orNull = NULL;
   }
 
   if (cpuFreq->options->show_label_freq || cpuFreq->options->show_label_governor)
   {
-    cpuFreq->label = gtk_label_new (NULL);
-    gtk_box_pack_start (GTK_BOX (cpufreq->box), cpuFreq->label, TRUE, TRUE, 0);
+    cpuFreq->label_orNull = gtk_label_new (NULL);
+    gtk_box_pack_start (GTK_BOX (cpufreq->box), cpuFreq->label_orNull, TRUE, TRUE, 0);
   }
 }
 
@@ -681,6 +755,7 @@ cpufreq_widgets (void)
 static void
 cpufreq_read_config (void)
 {
+  CpuFreqPluginOptions *const options = cpuFreq->options;
   XfceRc *rc;
   gchar  *file;
   const gchar *value;
@@ -696,32 +771,43 @@ cpufreq_read_config (void)
   rc = xfce_rc_simple_open (file, FALSE);
   g_free (file);
 
-  cpuFreq->options->timeout             = xfce_rc_read_int_entry  (rc, "timeout", 1);
-  if (cpuFreq->options->timeout > TIMEOUT_MAX || cpuFreq->options->timeout < TIMEOUT_MIN)
-    cpuFreq->options->timeout = TIMEOUT_MIN;
-  cpuFreq->options->show_cpu            = xfce_rc_read_int_entry  (rc, "show_cpu", CPU_DEFAULT);
-  cpuFreq->options->show_icon           = xfce_rc_read_bool_entry (rc, "show_icon", TRUE);
-  cpuFreq->options->show_label_freq     = xfce_rc_read_bool_entry (rc, "show_label_freq", TRUE);
-  cpuFreq->options->show_label_governor = xfce_rc_read_bool_entry (rc, "show_label_governor", TRUE);
-  cpuFreq->options->show_warning        = xfce_rc_read_bool_entry (rc, "show_warning", TRUE);
-  cpuFreq->options->keep_compact        = xfce_rc_read_bool_entry (rc, "keep_compact", FALSE);
-  cpuFreq->options->one_line            = xfce_rc_read_bool_entry (rc, "one_line", FALSE);
+  options->timeout             = xfce_rc_read_int_entry  (rc, "timeout", 1);
+  if (options->timeout > TIMEOUT_MAX || options->timeout < TIMEOUT_MIN)
+    options->timeout = TIMEOUT_MIN;
+  options->show_cpu            = xfce_rc_read_int_entry  (rc, "show_cpu", CPU_DEFAULT);
+  options->show_icon           = xfce_rc_read_bool_entry (rc, "show_icon", TRUE);
+  options->show_label_freq     = xfce_rc_read_bool_entry (rc, "show_label_freq", TRUE);
+  options->show_label_governor = xfce_rc_read_bool_entry (rc, "show_label_governor", TRUE);
+  options->show_warning        = xfce_rc_read_bool_entry (rc, "show_warning", TRUE);
+  options->keep_compact        = xfce_rc_read_bool_entry (rc, "keep_compact", FALSE);
+  options->one_line            = xfce_rc_read_bool_entry (rc, "one_line", FALSE);
+  options->unit                = xfce_rc_read_int_entry  (rc, "freq_unit", UNIT_DEFAULT);
 
-  if (!cpuFreq->options->show_label_freq && !cpuFreq->options->show_label_governor)
-    cpuFreq->options->show_icon = TRUE;
+  if (!options->show_label_freq && !options->show_label_governor)
+    options->show_icon = TRUE;
+
+  switch (options->unit)
+  {
+  case UNIT_AUTO:
+  case UNIT_GHZ:
+  case UNIT_MHZ:
+    break;
+  default:
+    options->unit = UNIT_DEFAULT;
+  }
 
   value = xfce_rc_read_entry (rc, "fontname", NULL);
   if (value)
   {
-    g_free (cpuFreq->options->fontname);
-    cpuFreq->options->fontname = g_strdup (value);
+    g_free (options->fontname);
+    options->fontname = g_strdup (value);
   }
 
   value = xfce_rc_read_entry (rc, "fontcolor", NULL);
   if (value)
   {
-    g_free (cpuFreq->options->fontcolor);
-    cpuFreq->options->fontcolor = g_strdup (value);
+    g_free (options->fontcolor);
+    options->fontcolor = g_strdup (value);
   }
 
   xfce_rc_close (rc);
@@ -732,6 +818,7 @@ cpufreq_read_config (void)
 void
 cpufreq_write_config (XfcePanelPlugin *plugin)
 {
+  const CpuFreqPluginOptions *const options = cpuFreq->options;
   XfceRc *rc;
   gchar  *file;
 
@@ -743,19 +830,20 @@ cpufreq_write_config (XfcePanelPlugin *plugin)
   rc = xfce_rc_simple_open (file, FALSE);
   g_free(file);
 
-  xfce_rc_write_int_entry  (rc, "timeout",             cpuFreq->options->timeout);
-  xfce_rc_write_int_entry  (rc, "show_cpu",            cpuFreq->options->show_cpu);
-  xfce_rc_write_bool_entry (rc, "show_icon",           cpuFreq->options->show_icon);
-  xfce_rc_write_bool_entry (rc, "show_label_freq",     cpuFreq->options->show_label_freq);
-  xfce_rc_write_bool_entry (rc, "show_label_governor", cpuFreq->options->show_label_governor);
-  xfce_rc_write_bool_entry (rc, "show_warning",        cpuFreq->options->show_warning);
-  xfce_rc_write_bool_entry (rc, "keep_compact",        cpuFreq->options->keep_compact);
-  xfce_rc_write_bool_entry (rc, "one_line",            cpuFreq->options->one_line);
+  xfce_rc_write_int_entry  (rc, "timeout",             options->timeout);
+  xfce_rc_write_int_entry  (rc, "show_cpu",            options->show_cpu);
+  xfce_rc_write_bool_entry (rc, "show_icon",           options->show_icon);
+  xfce_rc_write_bool_entry (rc, "show_label_freq",     options->show_label_freq);
+  xfce_rc_write_bool_entry (rc, "show_label_governor", options->show_label_governor);
+  xfce_rc_write_bool_entry (rc, "show_warning",        options->show_warning);
+  xfce_rc_write_bool_entry (rc, "keep_compact",        options->keep_compact);
+  xfce_rc_write_bool_entry (rc, "one_line",            options->one_line);
+  xfce_rc_write_int_entry  (rc, "freq_unit",           options->unit);
 
-  if (cpuFreq->options->fontname)
-    xfce_rc_write_entry  (rc, "fontname",            cpuFreq->options->fontname);
-  if (cpuFreq->options->fontcolor)
-    xfce_rc_write_entry  (rc, "fontcolor",           cpuFreq->options->fontcolor);
+  if (options->fontname)
+    xfce_rc_write_entry  (rc, "fontname",            options->fontname);
+  if (options->fontcolor)
+    xfce_rc_write_entry  (rc, "fontcolor",           options->fontcolor);
 
   xfce_rc_close (rc);
 }
@@ -834,7 +922,7 @@ cpufreq_show_about(XfcePanelPlugin *plugin,
      "program-name", PACKAGE_NAME,
      "comments", _("Show CPU frequencies and governor"),
      "website", PLUGIN_WEBSITE,
-     "copyright", _("Copyright (c) 2003-2020\n"),
+     "copyright", _("Copyright (c) 2003-2021\n"),
      "authors", auth,
      NULL);
 
