@@ -32,6 +32,15 @@
 #define CPU_MAX (-3)
 #define CPU_DEFAULT CPU_MAX
 
+typedef enum
+{
+  UNIT_AUTO,
+  UNIT_GHZ,
+  UNIT_MHZ,
+} CpuFreqUnit;
+
+#define UNIT_DEFAULT UNIT_GHZ
+
 typedef struct
 {
   guint  cur_freq;  /* frequency in kHz */
@@ -55,16 +64,17 @@ typedef struct
 
 typedef struct
 {
-  guint    timeout;       /* time between refresh */
-  gint     show_cpu;      /* cpu number in panel, or CPU_MIN/AVG/MAX */
-  gboolean show_icon;
-  gboolean show_label_governor;
-  gboolean show_label_freq;
-  gboolean show_warning;
-  gboolean keep_compact;
-  gboolean one_line;
-  gchar   *fontname;
-  gchar   *fontcolor;
+  guint       timeout;       /* time between refresh */
+  gint        show_cpu;      /* cpu number in panel, or CPU_MIN/AVG/MAX */
+  gboolean    show_icon;
+  gboolean    show_label_governor;
+  gboolean    show_label_freq;
+  gboolean    show_warning;
+  gboolean    keep_compact;
+  gboolean    one_line;
+  gchar      *fontname;
+  gchar      *fontcolor;
+  CpuFreqUnit unit;
 } CpuFreqPluginOptions;
 
 typedef struct
@@ -86,7 +96,7 @@ typedef struct
   IntelPState *intel_pstate;
 
   /* Widgets */
-  GtkWidget *button, *box, *icon, *label;
+  GtkWidget *button, *box, *icon, *label_orNull;
   GtkCssProvider *label_css_provider;
   gboolean layout_changed;
   gint label_max_width;
@@ -100,19 +110,22 @@ extern CpuFreqPlugin *cpuFreq;
 G_BEGIN_DECLS
 
 void
-cpuinfo_free (CpuInfo *cpu);
-
-gboolean
-cpufreq_update_plugin (gboolean reset_label_size);
+cpufreq_prepare_label (CpuFreqPlugin *cpufreq);
 
 void
 cpufreq_restart_timeout (void);
 
+void
+cpufreq_update_icon (CpuFreqPlugin *cpufreq);
+
+gboolean
+cpufreq_update_plugin (gboolean reset_label_size);
+
 void
 cpufreq_write_config (XfcePanelPlugin *plugin);
 
 void
-cpufreq_update_icon (CpuFreqPlugin *cpufreq);
+cpuinfo_free (CpuInfo *cpu);
 
 G_END_DECLS
 
